@@ -140,7 +140,7 @@ def freq(word_distribution,top_n=None, words=None, graph=True):
     elif top_n!=None and words !=None:
         print("debes pasar como argumento top_n o un arreglo words, no ambos")
     elif top_n!=None:
-        top=concept_freq_total.most_common(3)
+        top=concept_freq_total.most_common(top_n)
         if graph:
         
             x = [x[0] for x in top]
